#
# spec file for package kubernetes1.27
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.27
%define baseversionminus1 1.26

Name:           kubernetes%{baseversion}
Version:        1.27.14
Release:        1.1
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go >= 1.21.9
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.21
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.










# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Recommends:     kubernetes-kubelet-common = %{version}
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)
Recommends:     kubernetes%{baseversion}-kubelet

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes%{baseversion}-client-common
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Recommends:     bash-completion

%description client-common
Kubernetes client tools common files

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
BuildRequires:  bash-completion
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion

%description client-bash-completion
Bash command line completion support for %{name}-client

%package client-fish-completion
Summary:        Fish Completion for %{name}-client
Group:          System/Shells
BuildRequires:  fish
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and fish)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-fish-completion
Provides:       kubernetes-client-fish-completion = %{version}
Conflicts:      kubernetes-client-fish-completion

%description client-fish-completion
Fish command line completion support for %{name}-client.

%prep
%setup -q -n kubernetes-%{version}
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p0
%patch -P 5 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
%ifarch ppc64le
export GOLDFLAGS='-linkmode=external'
%endif

#TEST
export FORCE_HOST_GO=y
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# install the fish completion
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/kubectl%{baseversion} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/kubectl.fish

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
# Check if /etc/sysconfig/kubelet exists
if [ -e "/etc/sysconfig/kubelet" ]; then
  # Extract the value from the fillup file
  UPDATED_KUBELET_VER=$(grep '^KUBELET_VER=' %{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion} | cut -d '=' -f2)
  # Update the value in the sysconfig file
  sed -i "s/^KUBELET_VER=.*/KUBELET_VER=$UPDATED_KUBELET_VER/" /etc/sysconfig/kubelet
fi
%service_add_post kubelet.service
if [ $1 -eq 1 ]; then
    # Check if modprobe command is available
    [ ! -x /sbin/modprobe ] || { /sbin/modprobe br_netfilter && /sbin/modprobe overlay; } || true
fi
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%post kubeadm
# Check if sysctl command is available
if [ -x /usr/sbin/sysctl ]; then
    # Run sysctl --system after the package installation
    /usr/sbin/sysctl -p %{_sysctldir}/90-kubeadm.conf || true
fi

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%files client-fish-completion
%{_datadir}/fish/vendor_completions.d/kubectl.fish

%changelog
* Fri May 17 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.27.14:
  * scheduler: preallocation for NodeToStatusMap
  * add e2e test when a plugin (in-tree or out-of-tree) return non-existent/illegal nodes, the pod should be scheduled normally if suitable nodes exists
  * test to catch illegal nodeNames returned by PreFilterResult
  * add integration test for pod with pvc has node-affinity to non-existent/existent nodes
  * hotfix when a plugin (in-tree or out-of-tree) return non-existent/illegal nodes, the pod scheduling flow will abort immediately.
  * Fix PersistentVolumeLabel admission plugin on Azure
  * cluster/gce: upgrade cos-97-lts -> cos-109-lts
  * storage e2e: update hostpath and mock images
  * gce: fix test for non-existing instance in cloud
  * cloud-node-lifecycle controller: add fallback for empty providerID in shutdown
* Thu Apr 18 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.27.13:
  * Add envFrom to serviceaccount admission plugin
  * [go] Bump images, dependencies and versions to go 1.21.9 and distroless iptables
  * [CVE-2023-45288] .*: bump x/net to v0.23.0
  * Use the right feature gate when updating uncertain volumes
  * fix panic with SIGSEGV in kubeadm certs check-expiration
  * hack/tools: bump honnef.co/go/tools to v0.4.6
  * Serve watch without resourceVersion from cache and introduce a WatchFromStorageWithoutResourceVersion feature gate to allow serving watch from storage.
  * Use DBG=1 for conformance verification
  * build: use -trimpath in non-DBG mode
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.21.9`
  * ref: https://github.com/kubernetes/kubernetes/blob/v1.27.13/build/dependencies.yaml#L96-L98
* Mon Apr  8 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- update .spec file to set FORCE_HOST_GO env variable,
  to force k8s build scripts use the local GOTOOLCHAIN version from the build pipeline
  (i.e. GOTOOLCHAIN='auto')
  * ref: https://github.com/kubernetes/kubernetes/blob/9791f0d1f39f3f1e0796add7833c1059325d5098/hack/lib/golang.sh#L507
* Mon Apr  8 2024 priyanka.saggu@suse.com
- Update to version 1.27.12:
  * keep existing PDB conditions when updating status
  * remove --v arg from kubetest2-tester-ginkgo test args
  * ci: bump kind to latest for kms jobs
  * [go] Bump images, dependencies and versions to go 1.21.8 / distroless-iptables to v0.4.6
  * [CVE-2024-24786] Bump github.com/golang/protobuf v1.5.4, google.golang.org/protobuf v1.33.0
  * fix UT failure TestPrintIPAddressList
  * e2e_node: replace `registry.k8s.io/stress:v1` with agnhost
  * promote agnhost to v2.47
  * fixing issue with GetCPUUsageNanoCores on Windows
  * Fix cleanup of file subpaths
  * etcd: Update to version 3.5.12
  * build etcd image v3.5.12
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.21.8`
  * ref: https://github.com/kubernetes/kubernetes/blob/v1.27.12/build/dependencies.yaml#L96-L98
* Mon Feb 26 2024 priyanka.saggu@suse.com
- Update to version 1.27.11:
  * [go] Bump images, dependencies and versions to go 1.21.7 / distroless-iptables to v0.4.5
  * Revert "kubeadm: fix a bug where the uploaded kubelet configuration in kube-system/kubelet-config ConfigMap does not respect user patch"
  * Add processStartTime in metrics/slis
  * If a pvc has an empty storageclass name, don't try to assign a default StorageClass to it.
  * Drop PendingChanges methods from change trackers, move into UpdateResults
  * Squash some unnecessarily-chained methods in the change trackers
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  golang(API) = 1.21`
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Jan 24 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update .spec file to remove go version build requirements:
  * above build requirement causing build failures with following error:
  - `go: download go1.20.13 for linux/amd64: toolchain not available`
  - ref: https://go.dev/doc/toolchain
- Update to version 1.27.10:
  * Revert "Graduate Evented PLEG to Beta"
  * [go] Bump images, dependencies and versions to go 1.20.13 and distroless iptables to 0.2.9
  * e2e framework: adapt unit test to Go 1.22
  * Handle edge cases in seat demand stats
  * .*: bump golang.org/x/tools to v0.16.1
  * fix: 119921
  * Use a separate function for checking if device was reconstructed
  * Add tests for checking of uncertain device paths
  * Fix device uncertain errors on reboot
  * fix(scheduler): fix incorrect loop logic in MultiPoint to avoid a plugin being loaded multiple times
  * etcd: Update to version 3.5.10
  * fix: smb file share unavailable issue when it's deleted
* Wed Jan 24 2024 priyanka.saggu@suse.com
- Update to version 1.27.9:
  * run update-vendor script
  * [go] Bump images, dependencies and versions to go 1.20.12
  * pass GOTOOLCHAIN to build containers
  * handle GOTOOLCHAIN in kube::golang::verify_go_version
  * Move adding GroupVersion log until after an update is confirmed
  * fix: requeue pods rejected by Extenders properly
  * Bump distroless-iptables to 0.2.8 based on Go 1.20.11
  * Make StatefulSet restart pods with phase Succeeded
  * run hack scripts to update cyphar/filepath-securejoin to v0.2.4 correctly
  * update filepath-securejoin dependency to 0.2.4 to fix security vulnerability
  * Fix panic when process RunScorePlugins for cap out of range
  * e2e: bootstrap vsphere tests earlier
* Fri Nov 24 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.11`
- Update to version 1.27.8:
  * Use golang library instead of mklink
  * [go] Bump images, dependencies and versions to go 1.20.11
  * Fixing attempt to deploy past allocatable memory limits test on Windows
  * bump golang.org/grpc to v1.56.3
  * Add more test cases ensuring nextScheduleTimeDuration is never < 0
  * Modify mostRecentScheduleTime to return more detailed information about missed schedules
  * Fixing gmsa-webhook install steps for Windows GMSA full tests
  * removing the import of "k8s.io/utils/ptr" because it was introduced after 1.28
  * Fixing CurrentReplicas and CurrentRevision in completeRollingUpdate
  * KCCM: fix GCP ILB by reintroducing readiness predicate for eTP:Local
  * Use Patch instead of SSA for Pod Disruption condition
  * service controller: improve node lifecycle updates
  * Fix panic testing intree vSphere dynamic PV.
  * Retry operations if CSI Driver Isn't Found by Treating this Error as Transient
* Thu Oct 26 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.10`
- Update to version 1.27.7:
  * Release commit for Kubernetes v1.27.7
  * Register UnauthenticatedHTTP2DOSMitigation into kube components
  * Skip TestUnauthenticatedHTTP2ClientConnectionClose http1 tests
  * Disable UnauthenticatedHTTP2DOSMitigation by default
  * Prevent rapid reset http2 DOS on API server
  * Fix concurrent write when filling PVC labels
  * Modify test PVC to detect concurrent map write bug
  * [go] Bump images, dependencies and versions to go 1.20.10
  * Fix to honor PDB with an empty selector `{}`
  * .: bump golang.org/x/net to v0.17.0
  * Mark a volume as uncertain-attached after detach error
  * Add nil checks for hpa object target type values
  * [go] Bump images, versions and deps to use Go 1.20.9
  * bump etcd cluster image to 3.5.9
  * cronjob controller: ensure already existing jobs are added to Active list of cronjobs
  * change rolling update logic to exclude sunsetting nodes
  * vsphere: adapt to govmomi bump
  * .: bump govmomi to v0.30.6
  * move check for noop managed field timestamp updates
  * mount-utils: fix flaky test 'TestFormat'
  * Increase range of job_sync_duration_seconds
  * sync Service API status rest storage
  * updating dependencies.yaml for etcd v3.5.9 version
  * use upstream etcd github path instead of redirecting one
  * update etcd version in install.sh to 3.5.9
  * Update CHANGELOG/CHANGELOG-1.27.md for v1.27.6
  * fixup patcher test to include field manager
  * remove checks for fieldmanager from handlers
  * include apiextensions types in apiextensions generated openapi
  * fix scale not being given gvk in CRD openapi schemas
  * add OpenAPIV3 config to tests and server options
  * add error for attempting to initialize field manager with nil typeconverter
  * supply deduced typeconverter to apiserver tests
  * Throw error if OpenAPIV3 config is not provided
  * e2e pods: fix WaitForPodsResponding retry
  * scheduler: start scheduling attempt with clean UnschedulablePlugins
* Wed Sep 20 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- fixes for bsc#1214406
- update `Wants` directive in [Unit] section of `kubelet.service`:
  * add: `containerd.service`
  * remove: `docker.service`
- updating container runtime prerequisites:
  (Refer: k8s.io/docs/setup/production-environment/container-runtimes/#install-and-configure-prerequisites)
  * update `90-kubeadm.conf` to add below iptables rules:
  - net.bridge.bridge-nf-call-iptables = 1
  - net.bridge.bridge-nf-call-ip6tables = 1
  * update `kubeadm.conf` to add `overlay` kernel module
  * update .spec file to:
  - add post-installation scriptlet for `kubeadm` package to enable iptables rules defined in `90-kubeadm.conf` using sysctl
  - add conditional checks to load kernel modules (br_netfilter, overlay) in `kubelet-common` package post-installation scriptlet
  - update `kubelet-common` post scriptlet to correctly update `KUBELET_VER` var in `/etc/sysconfig/kubelet` file based on fillup template
- add below to `kubelet` subpackage to recommend installing correct version of package providing `kubernetes-kubelet-common` :
  * `Recommends: kubernetes-kubelet-common = %%{version}`
- add below to `kubeadm` subpackage to recommend installing correct version of `kubelet` and `kubelet-common` packages:
  * `Recommends: kubernetes%%{baseversion}-kubelet`
* Wed Sep 20 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.8`
- Update to version 1.27.6:
  * Release commit for Kubernetes v1.27.6
  * [go] Bump images, versions and deps to use Go 1.20.8
  * fix: concurrent map writes in e2e test
  * Automated cherry pick of #119776: Fix a job quota related deadlock (#120320)
  * Fix OpenAPI aggregation cleanup
  * Fallback to legacy discovery on a wider range of conditions in aggregator
  * apiextensions-apiserver: generate applyconfigurations
  * TopologyAwareHints: Take lock in HasPopulatedHints
  * Mark Job onPodConditions as optional in pod failure policy
  * Update CHANGELOG/CHANGELOG-1.27.md for v1.27.5
  * Incorporating feedback on 119341
  * check for overflow
  * Fix CEL cost handling of zero length replacement strings
  * generate ReportingInstance and ReportingController in Event
  * Pass Pinned field to kubecontainer.Image
  * prep for go1.21: use -e in go list
  * Skip apiserver_admission_webhook_request_total during context-canceled
  * Ignore context canceled from validate and mutate webhook failopen metric
  * kubeadm: fix nil pointer when etcd member is already removed
  * update to golangci-lint v1.54.1 + go-ruleguard v0.4.0
  * fix: when PreFilter returns UnschedulableAndUnresolvable, copy the state in all nodes in statusmap
  * Fix a bug that PostFilter plugin may not function if previous PreFilter plugins return Skip
  * Issue 4230: remove readiness check for cache exclusion
  * add test for apiservices.apiregistration.k8s.io discoverability in openapi/v3
  * update openapi
  * expose apiregistration.k8s.io into OpenAPIV3
  * fix openapi/v3 non local apiservices aggregation
  * node: devicemgr: topomgr: add logs
  * e2e: node: add test to check device-requiring pods are cleaned up
  * e2e: node: devices: improve the node reboot test
  * e2e: node: devicemanager: update tests
  * kubelet: devices: skip allocation for running pods
  * Add test coverage of result size of string operations
  * Bump cel-go to v0.12.7
* Tue Sep 12 2023 priyanka.saggu@suse.com
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.20.7`
- Update to version 1.27.5:
  * Use environment varaibles for parameters in Powershell
  * Use env varaibles for passing path
  * Avoid returning nil responseKind in v1beta1 aggregated discovery
  * [release-1.27] releng/go: Bump images, versions and deps to use Go 1.20.7
  * e2e_node: move getSampleDevicePluginPod to device_plugin_test.go
  * fix 'pod' in kubelet prober metrics
  * priority & fairness: support dynamically configuring work estimator max seats
  * Add mininumKubelet tag into ReadWriteOncePod test
  * Include ignored pods when computing backoff delay for Job pod failures
  * Adjust the algorithm for computing the pod finish time
  * Rename updateReconstructedFromAPIServer
  * Rename volumesNeedDevicePath
  * Update volumesInUse after attachability is confirmed
  * Add uncertain state of volume attach-ability
  * Refactor FindAttachablePluginBySpec out of CSI code path
  * kubeadm: backdate generated CAs by 5 minutes
  * client-go: allow to set NotBefore in NewSelfSignedCACert()
  * e2e: fix flaky test 'should contain OpenAPI V3 for Aggregated APIServer'
  * Fix a data race in TopologyCache
  * Fix TopologyAwareHint not working when zone label is added after Node creation
* Tue Aug  1 2023 Egbert Eich <eich@suse.com>
- Restore the correct content of the  kublet wrapper script (boo#1213829).
* Wed Jul 26 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update: `BuildRequires:  go >= 1.20.6`
- Update to version 1.27.4:
  * [release-1.27] releng/go: Bump images, versions and deps to use Go 1.20.6
  * Fix the converts an empty string to nil.
  * Add unit tests for parallel StatefulSet create & delete
  * Parallel StatefulSet pod create & delete
  * Refactor StatefulSet controller update logic
  * Only declare job as finished after removing all finalizers
  * Automated cherry pick of #118716 upstream release 1.27 (#118911)
  * Hide numberOfMissedSchedules as an algorithm internal number
  * Update schedule logic to properly calculate missed schedules
  * Automated cherry pick of #118805: test comment should match the code in podgc (#118913)
  * call ./hack/update-vendor.sh
  * kubeadm: remove function pointer comparison in phase test
  * CHANGELOG-1.27: Add note for AWS in-tree provider removal
  * Updating the nodeAffinity of gated pods having nil affinity should be allowed
  * fix the existing problem (0 SerialNumber in all certificate) as part of this PR in a separate commit
  * update serial number to a valid non-zero number in ca certificate
  * Delete CRDs created during field validation tests.
  * kubectl explain should work for both cluster and namespace resources and without a GET method
  * always execute condition for wait.PollUntilContextTimeout with immediate=true
  * Review remarks to improve HandlePodCleanups in kubelet
  * Fix the deletion of rejected pods
  * Unset gated pod info timestamp in addToActiveQ
  * deps: Bump to cAdvisor v0.47.2
  * Make etcd component status consistent with health probes
  * e2e storage: terminate worker quietly on test completion
  * Fix flaky persistent volumes e2e test
  * Set the node-ips annotation correctly with CloudDualStackNodeIPs
  * Fix the git-repo test error caused by the correct use of loop variables
  * dra scheduler plugin test: fix loopvar bug and "reserve" expected data
  * Add node check to vSphere cloud provider
  * Adding additional validations to queried endpoint list iteration.
* Wed Jun 21 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update: `BuildRequires:  go >= 1.20.5`
- Update to version 1.27.3:
  * Release commit for Kubernetes v1.27.3
  * update-vendor: update vendored go.sums
  * releng/go: Update images, dependencies and version to Go 1.20.5
  * kube-proxy avoid race condition using LocalModeNodeCIDR
  * Add ephemeralcontainer to imagepolicy securityaccount admission plugin
  * supported version of etcd 3.5.7-0 for Kubernetes v1.27.0-rc.0
  * e2e framework retry on Service unavailable errors
  * e2e: apply timeout for CSI Storage Capacity test only to node
  * Add DisruptionTarget condition when preempting for critical pod
  * update webhook test to go 1.21
  * Test APIService safe handling at startup
  * Fix waiting for CRD sync at server start
  * kubeadm: fix a bug where the static pod changes detection logic is inconsistent with kubelet
  * kubeadm: Make etcd member removal idempotent
  * kubeadm: Add etcd client unit tests
  * kubeadm: Use internal etcd client through an interface
* Mon Jun 12 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update: `BuildRequires:  go >= 1.20.4`
- Update to version 1.27.2:
  * Release commit for Kubernetes v1.27.2
  * OpenAPI V3 invalid document checks
  * QueryParamVerifier falls back on invalid v3 document
  * QueryParamVerifierV3 resilient to minimal OpenAPI V3 documents
  * kubeadm: fix a bug where file copy(backup) could not be executed correctly on Windows platform during upgrade
  * benchmark test to evaluate the overhead of podMatchesScopeFunc
  * Fix incorrect calculation for ResourceQuota with PriorityClass as its scope
  * Update podFailurePolicy comments from alpha-level to beta
  * Disable NewVolumeManagerReconstruction feature gate
  * releng/go: Update images, dependencies and version to Go 1.20.4
  * Bump konnectivity-client to v0.1.2
  * Kube-proxy/ipvs: accept access to healthCheckNodePort on LbIP
  * node: device-plugin: e2e: Additional test cases
  * node: device-plugin: add node reboot test scenario
  * node: device-plugin: e2e: Capture pod admission failure
  * node: device-mgr: e2e: adapt to sample device plugin refactoring
  * node: device-mgr: e2e: Update the e2e test to reproduce issue:109595
  * node: device-mgr: e2e: Implement End to end test
  * node: device-mgr: Handle recovery by checking if healthy devices exist
  * node: device-plugin: e2e: Add test case for kubelet restart
  * node: device-plugin: e2e: Provide sleep intervals via constants
  * node: device-plugin: e2e: Update test description to make it explicit
  * node: device-plugin: e2e: Isolate test to pod restart scenario
  * node: device-plugin: e2e: Annotate device check with error message
  * node: device-plugins: e2e: s/devLen/expectedSampleDevsAmount
  * node: device-plugins: e2e: Refactor parse log to return string and error
  * Update kube-openapi to fix race
  * Use absolute path instead requestURI in openapiv3 discovery
  * proxy/ipvs: don't bind nodeips to the dummy device
  * proxy/ipvs: add a GetAllLocalAddressesExcept() function
  * Refactors discovery content-type and helper functions
  * Fix scheduler performance regression after adding plugin metrics
  * Update staging/src/k8s.io/apiserver/pkg/cel/common/values.go
  * Fix bug where CEL listOfString.join() results in unexpected error
  * Fix directory mismatch for `volume.SetVolumeOwnership()`
  * Fix stomping os env in kubectl e2e tests
  * KCCM: add providerID predicate to service controller
  * Re-work logic in shouldSyncUpdatedNode
  * add log includes pod preemption details
  * verifyVolumeNoStatusUpdateNeeded may cause flake and so only keep the last ones
  * deflake: Add retry with timeout to wait for final conditions
  * kubelet: Mark new terminal pods as non-finished in pod worker
  * test: Add node e2e to restart kubelet while pod is terminating
  * kubelet: Ensure pods that have not started track a pendingUpdate
  * changelog: fix formatting issue with v1.27 change log
  * Update CHANGELOG/CHANGELOG-1.27.md for v1.27.1
  * use case-insensitive header keys for http probes
  * kube-aggregator: correctly use client-go TLS cache with custom dialer
  * api: encode NamespacedName with lower case in JSON
  * Do not look at VPC-related resources outside the cluster's network
  * Fix azure disk e2e after migration
  * vendor: bump runc to 1.1.6
  * CVE-2023-27561: Bump runc go module v1.1.4 -> v1.1.5
  * fix: the volume is not detached after the pod and PVC objects are deleted
  * Return error for localhost seccomp type with no localhost profile defined
* Fri Apr 28 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update `Requires` in the "kubernetes1.27-client" pkg to:
  * Requires: kubernetes%%{baseversion}-client-common
- Remove following `Obsoletes` from the "kubernetes1.27-client-common" pkg:
  * Obsoletes: kubernetes%%{baseversionminus1}-client-common
* Fri Apr 28 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.27.1:
  * Release commit for Kubernetes v1.27.1
  * fix: add the bug as a known issue o on the v1.26 release note
  * Revert "Optimization on running prePreEnqueuePlugins before adding pods into activeQ"
  * Revert "Merge pull request #113151 from ncdc/refactor-crd-conversion"
  * Revert "CR conversion: protect from converter input edits"
  * kubelet: Do not mutate pods in the pod manager
  * Update CHANGELOG/CHANGELOG-1.27.md for v1.27.0
* Wed Apr 12 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- update patches:
  * kubeadm-opensuse-registry.patch
  * revert-coredns-image-renaming.patch
* Wed Apr 12 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- initial package for Kubernetes v1.27.0
